"""Test exporting codebook to PDF."""
import unittest
import os
from pathlib import Path
from datetime import datetime
from soitool import codebook_to_pdf

SOITOOL_ROOT_PATH = Path(__file__).parent.parent


class ExportTest(unittest.TestCase):
    """Test codebook_to_pdf.py."""

    def test_generate_filename(self):
        """Test generated filename is as expected."""
        # Get current date in format YYYY_mm_dd
        today = datetime.now().strftime("%Y_%m_%d")

        # Assert correct filename for full codebook
        expected = f"Kodebok_{today}.pdf"
        actual = codebook_to_pdf.generate_filename(small=False)
        self.assertEqual(expected, actual)

        # Assert correct filename for small codebook
        expected = f"Kodebok_liten_{today}.pdf"
        actual = codebook_to_pdf.generate_filename(small=True)
        self.assertEqual(expected, actual)

    def test_generate_codebook_pdf(self):
        """Test generated PDF-file exist."""
        # Test full codebook (default)
        codebook_to_pdf.generate_codebook_pdf()
        file_name = codebook_to_pdf.generate_filename(small=False)
        file_path_full = os.path.join(SOITOOL_ROOT_PATH, file_name)
        # Assert file exists
        self.assertTrue(os.path.exists(file_path_full))

        # Test small codebook
        codebook_to_pdf.generate_codebook_pdf(small=True)
        file_name = codebook_to_pdf.generate_filename(small=True)
        file_path_small = os.path.join(SOITOOL_ROOT_PATH, file_name)
        # Assert file exists
        self.assertTrue(os.path.exists(file_path_small))

        # Delete files
        os.remove(file_path_full)
        os.remove(file_path_small)
